@@ -217,7 +217,14 @@ read_abs <- function(cat_no = NULL,
     xml_dfs <- xml_dfs %>%
       dplyr::group_by(SeriesID) %>%
       dplyr::filter(ProductReleaseDate == max(ProductReleaseDate)) %>%
-      dplyr::filter(row_number() == 1)
+      dplyr::filter(row_number() == 1) %>%
+      dplyr::ungroup()
+  } else {
+    xml_dfs <- xml_dfs %>%
+      dplyr::group_by(.data$TableURL) %>%
+      dplyr::filter(.data$ProductReleaseDate == max(.data$ProductReleaseDate)) %>%
+      dplyr::filter(.data$ProductReleaseDate == max(.data$ProductReleaseDate)) %>%
+      dplyr::ungroup()
   }
 
   urls <- unique(xml_dfs$TableURL)
