@@ -16,10 +16,12 @@ test_that("read_payrolls() works", {
   purrr::map(
     c(
       "industry_jobs",
+      "industry_wages",
       "sa4_jobs",
       "sa3_jobs",
       "subindustry_jobs",
-      "empsize_jobs"
+      "empsize_jobs",
+      "gccsa_jobs"
     ),
     ~ check_payrolls(.x)
   )
